library(mitml)
library(plyr)


# read stacked imputation data
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))
impdata <- read.table(paste0(getwd(), "/imps_stacked.dat"))
names(impdata) <- c("imputation", "id", "bullied", "bmi", "batt1", "batt2", "batt3", "batt4", "batt5")
impdata <- impdata[impdata$imputation > 0, ]

# compute scale score in each imputed data set and center covariate
impdata$bodyatt <- impdata$batt1 + impdata$batt2 + impdata$batt3 + impdata$batt4 + impdata$batt5
impdata <- ddply(impdata, c("imputation"), transform, bmic = scale(bmi, center = T, scale = F))

# analysis and pooling
implist <- as.mitml.list(split(impdata, impdata$imputation))
analysis <- with(implist, lm(bodyatt ~ bmic + bullied))
estimates <- testEstimates(analysis, var.comp = T)
estimates

# estimate empty model with no predictors
emptymodel <- with(implist, lm(bodyatt ~ 1))

# compare models with Wald test (e.g., MI version of omnibus F test)
testModels(analysis, emptymodel, method = "D1")

# compare models with likelihood ratio test (e.g., MI version of chi-square diff)
testModels(analysis, emptymodel, method = "D3")
