# Required packages
library(mitml)
library(plyr)

# read stacked data
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))
impdata <- read.table(paste0(getwd(),"/imps_stacked.dat"))
names(impdata) <- c("imputation", "id", "male", "age", "edugroup", "workhrs", "exercise", "pain", "anxiety", "stress", "control", "interfere", "depress", "disability")
impdata <- impdata[impdata$imputation > 0, ]

# center focal predictor 
impdata <- ddply(impdata, c("imputation"), transform, depressc = scale(depress, center = T, scale = F))

# analyze data and pool estimates
implist <- as.mitml.list(split(impdata, impdata$imputation))
analysis <- with(implist, lm(disability ~ depressc + male + depressc*male))
estimates <- testEstimates(analysis, var.comp = T, df.com = NULL)
estimates

# estimate empty model with no predictors
emptymodel <- with(implist, lm(disability ~ 1))

# compare models with Wald test (e.g., MI version of omnibus F test)
testModels(analysis, emptymodel, method = "D1")

# compare models with likelihood ratio test (e.g., MI version of chi-square diff)
testModels(analysis, emptymodel, method = "D3")
