/* read stacked imputation data */
data impdata (where = (_imputation_ gt 0));
infile '/folders/myfolders/imps_stacked.dat';
input _imputation_ id male age edugroup workhrs exercise pain anxiety stress control interfere depress disability; run;

/* center covariate at grand means in each data set */
proc means data = impdata noprint;
var depress;
by _imputation_;
output out = grandmeans (drop =_type_ _freq_) mean = depressmean; run;

data impdata;
merge impdata grandmeans;
by _imputation_;
depressc = depress - depressmean; 
product = depressc * male; run;

/* analyze imputations */
proc reg data = impdata outest = estimates covout noprint;
model disability = depressc male product;
by _imputation_;
run;

/* pool estimates and standard errors */
proc mianalyze data = estimates;
modeleffects Intercept depressc male product;
run;

/* omnibus test of model fit */
proc mianalyze data = estimates mult;
modeleffects depressc male product;
run;