# load lavaan sem package
library(lavaan)

# read data
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))
paindata <- read.table(paste0(getwd(),"/pain.dat"))
names(paindata) <- c("id", "male", "age", "edugroup", "workhrs", "exercise", "pain", "anxiety", "stress", "control", "interfere", "depress", "disability")

# missing data code
paindata[paindata == 999] <- NA

# specify model and label parameters for wald test
model <- '
disability ~ b1*depress + b2*male
depress ~~ male
'

# fit model and summarize estimates
analysis <- sem(model, paindata, missing = 'fiml', fixed.x = F, meanstructure = T, mimic = "Mplus")
summary(analysis, fit.measures = TRUE, rsquare = T, standardize = T)

# wald significance test (omnibus test of all predictors)
lavTestWald(analysis, 'b1 == 0 
            b2 == 0')

